require_relative "../catchid"
require 'typhoeus'
require 'json'

class Catchid::Client
	SERVER_URL = 'https://api.catchid.com/userapi/'
	attr_accessor :api_key, :api_version, :request_params

	def initialize api_key, args = {}
		@api_key = api_key
		@api_version = args[:api_version] || 'v1'
		# allowed params - timeout, proxy, proxyuserpwd
		@request_params = args.select{|k, _v| [:timeout, :proxy, :proxyuserpwd].include? k }
	end

	def info
		request = Typhoeus::Request.new(
			SERVER_URL + api_version + "/users",
			request_params.merge(
				method: :get,
				headers: { 'Content-Type': "application/json", 'Authorization': "Token #{api_key}" }
			)
		)
		response = request.run
		if response.success?
			JSON.parse(response.body)["credits"]
		else
			response
		end
	end

	def find data
		request = Typhoeus::Request.new(
			SERVER_URL + api_version + "/find",
			request_params.merge(
				method: :post,
				body: {data: data}.to_json,
				headers: { 'Content-Type': "application/json", 'Authorization': "Token #{api_key}" }
			)
		)
		response = request.run
		if response.success?
			JSON.parse(response.body)
		else
			response
		end
	end

	def show data
		request = Typhoeus::Request.new(
			SERVER_URL + api_version + "/show",
			request_params.merge(
				method: :post,
				body: {data: data}.to_json,
				headers: { 'Content-Type': "application/json", 'Authorization': "Token #{api_key}" }
			)
		)
		response = request.run
		if response.success?
			JSON.parse(response.body)
		else
			response
		end
	end


	private

	def create_request req
		req['Content-Type'] = 'application/json'
		req['Authorization'] = 'Token ' + @api_key
		req
	end
end